<?php
/**
 * Plugin Name: Launify Autocomplete
 * Plugin URI: https://launify.com
 * Description: Autocomplete plugin for WordPress with Launify
 * Version: 1.1
 * Author: Launify
 * Author URI: https://launify.com
 * License: GPL2
 * Text Domain: launify-autocomplete
 * Domain Path: /languages
 */

if (!defined('ABSPATH')) {
    exit;
}

// Přidání menu do administrace
function launify_add_admin_menu() {
    add_options_page(
        __('Launify Settings', 'launify-autocomplete'),
        'Launify',
        'manage_options',
        'launify-autocomplete',
        'launify_admin_page'
    );
}
add_action('admin_menu', 'launify_add_admin_menu');

// Vykreslení administrační stránky
function launify_admin_page() {
    $help_url = "https://launify.com/i/wordpress";
    ?>
    <div class="wrap">
        <h1><img src="https://app.launify.com/assets/img/logo-ct.png" href="https://launify.com/" alt="Launify" style="height: 40px;"></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('launify_options_group');
            do_settings_sections('launify-autocomplete');
            submit_button();
            ?>
        </form>
        <p><?php _e('For more information and instructions:', 'launify-autocomplete'); ?> <a href="<?php echo esc_url($help_url); ?>" target="_blank"><?php _e('View instructions', 'launify-autocomplete'); ?></a></p>
    </div>
    <?php
}

// Registrace nastavení
function launify_register_settings() {
    register_setting('launify_options_group', 'launify_api_key');
    add_settings_section('launify_section', __('API Key Settings', 'launify-autocomplete'), null, 'launify-autocomplete');
    add_settings_field('launify_api_key', __('API Key', 'launify-autocomplete'), 'launify_api_key_field', 'launify-autocomplete', 'launify_section');
}
add_action('admin_init', 'launify_register_settings');

// Pole pro API klíč
function launify_api_key_field() {
    $api_key = get_option('launify_api_key', '');
    echo '<input type="text" name="launify_api_key" value="' . esc_attr($api_key) . '" style="width: 100%;">';
}

// Vložení měřícího kódu do hlavičky
function launify_insert_tracking_code() {
    $api_key = get_option('launify_api_key');
    if (!$api_key) return;

    echo "<script>
        window.onload = () => document.head.appendChild(Object.assign(document.createElement('script'), {
            src: 'https://cdn.launify.com/launify.min.js?t=' + Date.now(),
            onload: () => new Launify('$api_key').init(),
            async: true
        }));
    </script>";
}
add_action('wp_head', 'launify_insert_tracking_code');

// Načtení překladů
function launify_load_textdomain() {
    load_plugin_textdomain('launify-autocomplete', false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'launify_load_textdomain');
